@@ -29,7 +29,7 @@ from ._models import (KeyValue,
                       convert_configurationsetting_to_keyvalue,
                       convert_keyvalue_to_configurationsetting)
 from ._utils import (get_appconfig_data_client,
-                     prep_label_filter_for_url_encoding,
+                     prep_filter_for_url_encoding,
                      validate_feature_flag_name)
 from ._featuremodels import (map_keyvalue_to_featureflag,
                              map_keyvalue_to_featureflagvalue,
@@ -51,7 +51,8 @@ def set_feature(cmd,
                 yes=False,
                 connection_string=None,
                 auth_mode="key",
-                endpoint=None):
+                endpoint=None,
+                tags=None):
     if key is None and feature is None:
         raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
 
@@ -67,11 +68,14 @@ def set_feature(cmd,
             raise exception
 
     # when creating a new Feature flag, these defaults will be used
-    tags = {}
     default_conditions = {FeatureFlagConstants.CLIENT_FILTERS: []}
 
     if requirement_type:
-        default_conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = requirement_type
+        default_conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = (
+            FeatureFlagConstants.REQUIREMENT_TYPE_ALL
+            if requirement_type.lower() == FeatureFlagConstants.REQUIREMENT_TYPE_ALL.lower()
+            else FeatureFlagConstants.REQUIREMENT_TYPE_ANY
+        )
 
     default_value = {
         FeatureFlagConstants.ID: feature,
@@ -125,7 +129,11 @@ def set_feature(cmd,
                     feature_flag_value.description = description
 
                 if requirement_type is not None:
-                    feature_flag_value.conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = requirement_type
+                    feature_flag_value.conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = (
+                        FeatureFlagConstants.REQUIREMENT_TYPE_ALL
+                        if requirement_type.lower() == FeatureFlagConstants.REQUIREMENT_TYPE_ALL.lower()
+                        else FeatureFlagConstants.REQUIREMENT_TYPE_ANY
+                    )
 
                 set_kv = KeyValue(key=key,
                                   label=label,
@@ -137,6 +145,7 @@ def set_feature(cmd,
 
             # Convert KeyValue object to required FeatureFlag format for
             # display
+
             feature_flag = map_keyvalue_to_featureflag(set_kv, show_all_details=True)
             entry = json.dumps(feature_flag, default=lambda o: o.__dict__, indent=2, sort_keys=True, ensure_ascii=False)
 
@@ -177,7 +186,8 @@ def delete_feature(cmd,
                    yes=False,
                    connection_string=None,
                    auth_mode="key",
-                   endpoint=None):
+                   endpoint=None,
+                   tags=None):
     if key is None and feature is None:
         raise CLIErrors.RequiredArgumentMissingError("Please provide either `--key` or `--feature` value.")
     if key and feature:
@@ -196,9 +206,10 @@ def delete_feature(cmd,
     retrieved_keyvalues = __list_all_keyvalues(azconfig_client,
                                                key_filter=key_filter,
                                                label=SearchFilterOptions.EMPTY_LABEL if label is None else label,
-                                               correlation_request_id=correlation_request_id)
+                                               correlation_request_id=correlation_request_id,
+                                               tags=tags)
 
-    confirmation_message = "Found '{}' feature flags matching the specified feature and label. Are you sure you want to delete these feature flags?".format(len(retrieved_keyvalues))
+    confirmation_message = "Found '{}' feature flags matching the specified feature, label, and tags. Are you sure you want to delete these feature flags?".format(len(retrieved_keyvalues))
     user_confirmation(confirmation_message, yes)
 
     deleted_kvs = []
@@ -296,7 +307,8 @@ def list_feature(cmd,
                  top=None,
                  all_=False,
                  auth_mode="key",
-                 endpoint=None):
+                 endpoint=None,
+                 tags=None):
     return __list_features(
         cmd=cmd,
         feature=feature,
@@ -308,7 +320,8 @@ def list_feature(cmd,
         top=top,
         all_=all_,
         auth_mode=auth_mode,
-        endpoint=endpoint
+        endpoint=endpoint,
+        tags=tags
     )
 
 
@@ -1031,6 +1044,7 @@ def __list_features(
     key=None,
     name=None,
     label=None,
+    tags=None,
     fields=None,
     connection_string=None,
     top=None,
@@ -1061,6 +1075,7 @@ def __list_features(
             azconfig_client,
             key_filter=key_filter,
             label=label if label else SearchFilterOptions.ANY_LABEL,
+            tags=tags,
             correlation_request_id=correlation_request_id,
         )
         retrieved_featureflags = []
@@ -1230,6 +1245,7 @@ def __update_existing_key_value(azconfig_client,
 def __list_all_keyvalues(azconfig_client,
                          key_filter,
                          label=None,
+                         tags=None,
                          correlation_request_id=None):
     '''
         To get all keys by name or pattern
@@ -1238,6 +1254,7 @@ def __list_all_keyvalues(azconfig_client,
             azconfig_client - AppConfig client making calls to the service
             key_filter - Filter for the key of the feature flag
             label - Feature label or pattern
+            tags - Tags to filter the feature flags
 
         Return:
             List of KeyValue objects
@@ -1251,10 +1268,11 @@ def __list_all_keyvalues(azconfig_client,
     if unescaped_comma_regex.search(key_filter):
         raise CLIError("Comma separated feature names are not supported. Please provide escaped string if your feature name contains comma. \nSee \"az appconfig feature list -h\" for correct usage.")
 
-    label = prep_label_filter_for_url_encoding(label)
+    label = prep_filter_for_url_encoding(label)
+    prepped_tags = [prep_filter_for_url_encoding(tag) for tag in tags] if tags else []
 
     try:
-        configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
+        configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label, tags_filter=prepped_tags, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
     except HttpResponseError as exception:
         raise CLIErrors.AzureResponseError('Failed to read feature flag(s) that match the specified feature and label. ' + str(exception))
 
