@@ -348,6 +348,10 @@ def load_command_table(self, _):
         g.show_command('show', 'get')
         g.custom_command('list', 'list_long_term_retention_backups')
         g.command('delete', 'begin_delete', confirmation=True)
+        g.custom_command('remove-time-based-immutability', 'remove_time_based_immutability', confirmation="Removing the time-based immutability has the effect of removing the immutability on the backup. The backup will continue to be available for the remainder of the configured duration as usual, without immutability. Are you sure you want to disable time-based immutability for the backup?", is_preview=True)
+        g.custom_command('lock-time-based-immutability', 'lock_time_based_immutability', confirmation="Locking the time-based immutability enforces immutability for the duration of the configured retention. This action cannot be reversed. Are you sure you want to lock time-based immutability for the backup?", is_preview=True)
+        g.custom_command('set-legal-hold-immutability', 'set_legal_hold_immutability', confirmation="When you enable Legal hold immutability on the backup, the backup will not be deleted until the legal hold is removed, even if the retention for the backup expires. Are you sure you want to enable legal hold for the backup?", is_preview=True)
+        g.custom_command('remove-legal-hold-immutability', 'remove_legal_hold_immutability', confirmation="Are you sure you want to disable legal hold for the backup?", is_preview=True)
 
     with self.command_group('sql db ltr-backup',
                             database_operations,
