@@ -67,14 +67,6 @@ def cf_images(cli_ctx, _):
     return _compute_client_factory(cli_ctx).images
 
 
-def cf_run_commands(cli_ctx, _):
-    return _compute_client_factory(cli_ctx).virtual_machine_run_commands
-
-
-def cf_vmss_run_commands(cli_ctx, _):
-    return _compute_client_factory(cli_ctx).virtual_machine_scale_set_vm_run_commands
-
-
 def cf_rolling_upgrade_commands(cli_ctx, _):
     return _compute_client_factory(cli_ctx).virtual_machine_scale_set_rolling_upgrades
 
