@@ -7,13 +7,12 @@ from azure.cli.command_modules.vm._client_factory import (cf_vm,
                                                           cf_vm_ext, cf_vm_ext_image,
                                                           cf_vm_image, cf_vm_image_term, cf_usage,
                                                           cf_vmss, cf_disks, cf_snapshots,
-                                                          cf_images, cf_run_commands,
+                                                          cf_images,
                                                           cf_galleries, cf_gallery_images, cf_gallery_image_versions,
                                                           cf_proximity_placement_groups,
                                                           cf_dedicated_hosts, cf_dedicated_host_groups,
                                                           cf_log_analytics_data_plane,
                                                           cf_capacity_reservation_groups, cf_capacity_reservations,
-                                                          cf_vmss_run_commands,
                                                           cf_restore_point,
                                                           cf_restore_point_collection, cf_community_gallery)
 from azure.cli.command_modules.vm._format import (
@@ -111,14 +110,12 @@ def load_command_table(self, _):
         client_factory=cf_usage
     )
 
-    compute_vm_run_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#VirtualMachineRunCommandsOperations.{}',
-        client_factory=cf_run_commands
+    compute_vm_run_profile = CliCommandType(
+        operations_tmpl='azure.mgmt.compute.operations#VirtualMachineRunCommandsOperations.{}'
     )
 
     compute_vmss_run_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#VirtualMachineScaleSetVmRunCommandsOperations.{}',
-        client_factory=cf_vmss_run_commands
+        operations_tmpl='azure.mgmt.compute.operations#VirtualMachineScaleSetVmRunCommandsOperations.{}'
     )
 
     compute_vmss_sdk = CliCommandType(
@@ -377,13 +374,12 @@ def load_command_table(self, _):
         g.custom_show_command('show', 'show_vm_nic')
         g.custom_command('list', 'list_vm_nics')
 
-    with self.command_group('vm run-command', compute_vm_run_sdk, client_factory=cf_run_commands, operation_group='virtual_machine_run_commands', min_api='2017-03-30') as g:
+    with self.command_group('vm run-command', compute_vm_run_profile, operation_group='virtual_machine_run_commands') as g:
         g.custom_command('invoke', 'vm_run_command_invoke', supports_no_wait=True)
         g.custom_command('list', 'vm_run_command_list')
         g.custom_show_command('show', 'vm_run_command_show')
         g.custom_command('create', 'vm_run_command_create', supports_no_wait=True)
         g.custom_command('update', 'vm_run_command_update', supports_no_wait=True)
-        g.custom_command('delete', 'vm_run_command_delete', supports_no_wait=True, confirmation=True)
         g.custom_wait_command('wait', 'vm_run_command_show')
 
     with self.command_group('vm secret', compute_vm_sdk) as g:
@@ -465,13 +461,11 @@ def load_command_table(self, _):
     with self.command_group('vmss extension image', compute_vm_extension_image_sdk) as g:
         g.custom_command('list', 'list_vm_extension_images')
 
-    with self.command_group('vmss run-command', compute_vmss_run_sdk, client_factory=cf_vmss_run_commands, min_api='2018-04-01') as g:
+    with self.command_group('vmss run-command', compute_vmss_run_sdk) as g:
         g.custom_command('invoke', 'vmss_run_command_invoke')
-        g.custom_command('list', 'vmss_run_command_list')
         g.custom_show_command('show', 'vmss_run_command_show')
         g.custom_command('create', 'vmss_run_command_create', supports_no_wait=True)
         g.custom_command('update', 'vmss_run_command_update', supports_no_wait=True)
-        g.custom_command('delete', 'vmss_run_command_delete', supports_no_wait=True, confirmation=True)
 
     with self.command_group('sig', compute_galleries_sdk, operation_group='galleries') as g:
         from .operations.sig import SigCreate, SigUpdate, SigShow
