@@ -206,7 +206,7 @@ AZURE_API_PROFILES = {
         ResourceType.DATA_KEYVAULT_ADMINISTRATION_ACCESS_CONTROL: '7.4',
         ResourceType.DATA_STORAGE_BLOB: '2022-11-02',
         ResourceType.DATA_STORAGE_FILEDATALAKE: '2021-08-06',
-        ResourceType.DATA_STORAGE_FILESHARE: '2025-05-05',
+        ResourceType.DATA_STORAGE_FILESHARE: '2025-07-05',
         ResourceType.DATA_STORAGE_QUEUE: '2018-03-28',
         ResourceType.DATA_STORAGE_TABLE: None,
         ResourceType.MGMT_SERVICEBUS: None,
@@ -214,9 +214,9 @@ AZURE_API_PROFILES = {
         ResourceType.MGMT_MONITOR: None,
         ResourceType.MGMT_MSI: '2023-01-31',
         ResourceType.MGMT_APPSERVICE: '2024-11-01',
-        ResourceType.MGMT_IOTHUB: '2023-06-30-preview',
-        ResourceType.MGMT_IOTDPS: '2021-10-15',
-        ResourceType.MGMT_IOTCENTRAL: '2021-11-01-preview',
+        ResourceType.MGMT_IOTHUB: None,
+        ResourceType.MGMT_IOTDPS: None,
+        ResourceType.MGMT_IOTCENTRAL: None,
         ResourceType.MGMT_ARO: '2023-11-22',
         ResourceType.MGMT_DATABOXEDGE: '2021-02-01-preview',
         ResourceType.MGMT_CUSTOMLOCATION: '2021-03-15-preview',
